Storage

Trait Storage 

pub trait Storage {
    // Required method
    fn txn<'a>(&'a mut self) -> Result<Box<dyn StorageTxn + 'a>, Error>;
}
A trait for objects able to act as task storage. Most of the interesting behavior is in the crate::storage::StorageTxn trait.

Required Methods

fn txn<'a>(&'a mut self) -> Result<Box<dyn StorageTxn + 'a>, Error>

Begin a transaction

Implementors