Operations

Type Alias Operations 

pub type Operations = Vec<Operation>;
Operations are a sequence of Operation values, which can be committed in a single transaction with Replica::commit_operations.

Aliased Type

pub struct Operations { /* private fields */ }